# Python nexusdb

Your nexusdb is a lightweight JSON-based database system for Python, providing an easy way to store and manage structured data within your Python applications.

## Installation

You can install nexusdb using pip:

```shell
pip install nexusdb
